MethodChannelSharedPreferencesStore class

Wraps NSUserDefaults (on iOS) and SharedPreferences (on Android), providing a persistent store for simple data.

Data is persisted to disk asynchronously.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMock → bool
Only mock implementations should set this to true.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<bool>
Removes all keys and values in the store where the key starts with 'flutter.'.
override
clearWithParameters(ClearParameters parameters) → Future<bool>
Removes all keys and values in the store that match options.
override
clearWithPrefix(String prefix) → Future<bool>
Removes all keys and values in the store with given prefix.
override
getAll() → Future<Map<String, Object>>
Returns all key/value pairs persisted in this store where the key starts with 'flutter.'.
override
getAllWithParameters(GetAllParameters parameters) → Future<Map<String, Object>>
Returns all key/value pairs persisting in this store that match options.
override
getAllWithPrefix(String prefix, {Set<String>? allowList}) → Future<Map<String, Object>>
Returns all key/value pairs persisting in this store that have given prefix.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<bool>
Removes the value associated with the key.
override
setValue(String valueType, String key, Object value) → Future<bool>
Stores the value associated with the key.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited